========
vivodict
========


.. image:: https://img.shields.io/pypi/v/vivodict.svg
        :target: https://pypi.python.org/pypi/vivodict

.. image:: https://img.shields.io/travis/somada141/vivodict.svg
        :target: https://travis-ci.org/somada141/vivodict

.. image:: https://readthedocs.org/projects/vivodict/badge/?version=latest
        :target: https://vivodict.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/somada141/vivodict/shield.svg
     :target: https://pyup.io/repos/github/somada141/vivodict/
     :alt: Updates


Auto-vivified arbitrarily-nested dictionary (`dict`) classes.


* Free software: MIT license
* Documentation: https://vivodict.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

